This project is designed to analyze credit card transactions data and predict credit card fraud. 

<div class="alert">
 Note that as an AI or business insights consumer, you are not expected to understand all of the steps of the project, especially if you are just getting started with Dataiku DSS. You can nevertheless use this wiki as a reference point, and come back to it throughout the project.
</div>

# Deliverables

The project produces consumable insights in three notable deliverables:

- the [Purchase Patterns](dashboard:oLeWRKL_purchase-patterns) dashboard, which contains charts analyzing transaction patterns, and will also store the insights that you will create and publish over the course of the tutorial;
- the [Model Report & Predictions](dashboard:ZTixLn7_model-report-predictions) dashboard, which contains details about the machine learning model and its performance, as well as the list of transactions that were predicted to be fraudulent by the model;
- the [AI Consumer App (Tutorial)](/apps/PROJECT_QS_AI_CONSUMER) Dataiku application, which you will use to upload a new dataset with credit card transactions, and generate consumable insights and predictions on new data. 

# Overview

Most of the visual data analysis is performed on the [transactions_joined_prepared](dataset:transactions_joined_prepared) dataset. Each row in this dataset represents one individual credit card transaction, and contains information such as: 
- the ID of the transaction;
- the ID of the card the transaction was made with; 
- the date, as well as the year, of the purchase;
- the purchase amount;
- the ID of the merchant that the transaction was made to, as well as its subsector (e.g. gas, internet, etc.);
- whether the transaction was authorized (represented by the value ``1`` in the *authorized_flag* column) or flagged as fraudulent (represented by the value ``0`` in the *authorized_flag* column); etc.

For some of the transactions, the value of *authorized_flag*  is empty, which means that it is unknown whether they are authorized or fraudulent. In order to identify and flag the potentially fraudulent transactions, this project:
- splits the **transactions_joined_prepared** dataset into [transactions_known](dataset:transactions_known) and [transactions_unknown](dataset:transactions_unknown);
- uses the **transactions_known** dataset to train a machine learning model;
- which then predicts which transactions in the **transactions_unknown** dataset are fraudulent and stores the predictions in the *prediction* column of the [transactions_unknown_scored](dataset:transactions_unknown_scored) dataset.

---

# Detailed Step-by-Step Project Description

## Preparing the Data for Analysis 

 - The input datasets [transactions](dataset:transactions), [cardholder_info](dataset:cardholder_info), and [merchant_info](dataset:merchant_info) are CSV files.
 
 - The [Join recipe](recipe:compute_transactions_joined) joins the  **transactions_stacked**, **cardholder_info**,  and  **merchant_info**  datasets into one dataset, [transactions_joined](dataset:transactions_joined).
 
 - The [Prepare recipe](recipe:compute_transactions_joined_prepared) parses dates, extracts date components from the *purchase_date* column, and computes the *days_active* column.
 
## Preparing the Data for Machine Learning 
 
 - The [Split recipe](recipe:split_transactions_joined_prepared) splits the **transactions_joined_prepared** dataset into [transactions_known](dataset:transactions_known) and [transactions_unknown](dataset:transactions_unknown), based on whether the *authorized_flag* column value is defined or not.  
 
## Training and Scoring the Model

  - The **transactions_known** dataset  is used to [train](recipe:train_Prediction__RANDOM_FOREST_CLASSIFICATION__on_transactions_known) the model.

  - The [Quick Modeling analysis](analysis:COYme3Qz) uses binary classification to predict the target, *authorized_flag*.
 
- The deployed [Random Forest model](saved_model:PVmByyrP) is optimized for ROC AUC. 

- The [Scoring recipe](recipe:score_transactions_unknown) and the [transactions_unknown](dataset:transactions_unknown) dataset are used to score the model and output predictions in [transactions_unknown_scored](dataset:transactions_unknown_scored).

---